@@ -2,6 +2,8 @@
 
 # BSD 3-Clause License; see https://github.com/scikit-hep/uproot/blob/master/LICENSE
 
+from __future__ import absolute_import
+
 import uproot
 import uproot._connect._pandas
 
@@ -518,7 +520,12 @@ tree_fragments = {
 
     # i
     "i": u"""i : non-negative int
-        basket number (must be greater than or equal to zero and strictly less than *numbaskets*)."""
+        basket number (must be greater than or equal to zero and strictly less than *numbaskets*).""",
+
+    # chunked
+    "chunked": u"""chunked : bool
+        if ``True`` *(default)*, produced chunked lazy arrays using awkward.ChunkedArray.   If ``False``, produce bare VirtualArrays.  This option implies ``entrysteps = float('inf')``.""",
+
     }
 
 ################################################################ uproot.tree.iterate
@@ -988,9 +995,11 @@ u"""Create a lazy array that would read the branch as needed.
 
     {persistvirtual}
 
+    {chunked}
+
     Returns
     -------
-    ChunkedArray of VirtualArrays
+    ChunkedArray of VirtualArrays or VirtualArray
         lazy version of the array.
 """.format(**tree_fragments)
 
@@ -1025,9 +1034,11 @@ u"""Create a table of lazy arrays.
 
     {persistvirtual}
 
+    {chunked}
+
     Returns
     -------
-    ChunkedArray of Table of VirtualArrays
+    ChunkedArray of Table of VirtualArrays or Table of VirtualArrays
         lazy branch data.
 """.format(**tree_fragments)
 
@@ -1516,9 +1527,11 @@ u"""Create a lazy array that would read the branch as needed.
 
     {persistvirtual}
 
+    {chunked}
+
     Returns
     -------
-    ChunkedArray of VirtualArrays
+    ChunkedArray of VirtualArrays or VirtualArray
         lazy version of branch data.
 """.format(**tree_fragments)
 
@@ -1693,7 +1706,7 @@ u"""Create a lazy array that would read from a set of files as needed.
 
     Returns
     -------
-    ChunkedArray of VirtualArrays of VirtualArrays
+    ChunkedArray of VirtualArrays
         lazy files of lazy baskets.
 """.format(**dict(list(open_fragments.items()) + list(tree_fragments.items())))
 
@@ -1741,7 +1754,7 @@ u"""Create a lazy table that would read from a set of files as needed.
 
     Returns
     -------
-    ChunkedArray of Table of VirtualArrays of VirtualArrays
+    ChunkedArray of Table of VirtualArrays
         lazy files of branches of lazy baskets.
 """.format(**dict(list(open_fragments.items()) + list(tree_fragments.items())))
 
@@ -1900,7 +1913,7 @@ u"""Interface for interpretations.
     **source_numitems(self, source)**
         calculate the number of "items" given a ``source`` instance.
 
-    **fromroot(self, data, offsets, local_entrystart, local_entrystop)**
+    **fromroot(self, data, offsets, local_entrystart, local_entrystop, keylen)**
         produce a source from one basket ``data`` array (dtype ``numpy.uint8``) and its corresponding ``offsets`` array (dtype **numpy.int32** or ``None`` if not present) that has *n + 1* elements for *n* entries: ``offsets[0] == 0 and offsets[-1] == numentries``. The ``local_entrystart`` and ``local_entrystop`` are entry start (inclusive) and stop (exclusive), in which the first entry in the basket is number zero (hence "local"). The result of this operation may be a zero-copy cast of the basket data.
 
     **destination(self, numitems, numentries)**
